=== added directory 'apt-xapian-index-plugin'
=== added file 'apt-xapian-index-plugin/origin.py'
--- apt-xapian-index-plugin/origin.py	1970-01-01 00:00:00 +0000
+++ apt-xapian-index-plugin/origin.py	2010-02-02 01:04:28 +0000
@@ -0,0 +1,98 @@
+# Add debtags tags to the index
+
+import apt
+import re
+import os
+
+
+
+class OriginPlugin:
+    def info(self):
+        """
+        Return general information about the plugin.
+
+        The information returned is a dict with various keywords:
+         
+         timestamp (required)
+           the last modified timestamp of this data source.  This will be used
+           to see if we need to update the database or not.  A timestamp of 0
+           means that this data source is either missing or always up to date.
+         values (optional)
+           an array of dicts { name: name, desc: description }, one for every
+           numeric value indexed by this data source.
+
+        Note that this method can be called before init.  The idea is that, if
+        the timestamp shows that this plugin is currently not needed, then the
+        long initialisation can just be skipped.
+        """
+        file = apt.apt_pkg.Config.FindFile("Dir::Cache::pkgcache")
+        return dict(timestamp = os.path.getmtime(file))
+
+    def init(self, info, progress):
+        """
+        If needed, perform long initialisation tasks here.
+
+        info is a dictionary with useful information.  Currently it contains
+        the following values:
+
+          "values": a dict mapping index mnemonics to index numbers
+
+        The progress indicator can be used to report progress.
+        """
+        pass
+
+    def doc(self):
+        """
+        Return documentation information for this data source.
+
+        The documentation information is a dictionary with these keys:
+          name: the name for this data source
+          shortDesc: a short description
+          fullDoc: the full description as a chapter in ReST format
+        """
+        return dict(
+            name = "Origin",
+            shortDesc = "Origin information",
+            fullDoc = """
+            The Origin data source indexes origin information
+            It uses the prefix XO
+            """
+        )
+
+
+    def index(self, document, pkg):
+        """
+        Update the document with the information from this data source.
+
+        document  is the document to update
+        pkg       is the python-apt Package object for this package
+        """
+        ver = pkg.candidate
+        if ver is None: 
+            return
+        for origin in ver.origins:
+            document.add_term("XOA"+origin.archive)
+            document.add_term("XOC"+origin.component)
+            document.add_term("XOL"+origin.label)
+            document.add_term("XOO"+origin.origin)
+            document.add_term("XOS"+origin.site)
+
+    def indexDeb822(self, document, pkg):
+        """
+        Update the document with the information from this data source.
+
+        This is alternative to index, and it is used when indexing with package
+        data taken from a custom Packages file.
+
+        document  is the document to update
+        pkg       is the Deb822 object for this package
+        """
+        # NOTHING here, does not make sense for non-downloadable data
+        return
+
+
+def init():
+    """
+    Create and return the plugin object.
+    """
+    return OriginPlugin()

=== modified file 'softwarecenter/db/update.py'
--- softwarecenter/db/update.py	2010-01-18 10:51:14 +0000
+++ softwarecenter/db/update.py	2010-02-02 01:04:28 +0000
@@ -173,6 +173,12 @@
             elif pkgname in cache and cache[pkgname].candidate:
                 s = cache[pkgname].candidate.summary
                 doc.add_value(XAPIAN_VALUE_SUMMARY, s)
+                for origin in ver.origins:
+                    document.add_term("XOA"+origin.archive)
+                    document.add_term("XOC"+origin.component)
+                    document.add_term("XOL"+origin.label)
+                    document.add_term("XOO"+origin.origin)
+                    document.add_term("XOS"+origin.site)
 
             # add packagename as meta-data too
             term_generator.index_text_without_positions(pkgname, WEIGHT_APT_PKGNAME)

=== modified file 'softwarecenter/view/appview.py'
--- softwarecenter/view/appview.py	2010-01-28 08:41:52 +0000
+++ softwarecenter/view/appview.py	2010-02-02 01:04:28 +0000
@@ -719,7 +719,7 @@
         # FIXME: mvo this makes everything sluggish but its the only
         #        way to make the rows grow (sluggish because gtk will
         #        use a lot of the handlers to validate the treeview)
-        #self.set_fixed_height_mode(True)
+        self.set_fixed_height_mode(True)
         self.set_headers_visible(False)
         tp = CellRendererPixbufWithOverlay("software-center-installed")
         column = gtk.TreeViewColumn("Icon", tp,

=== modified file 'softwarecenter/view/pendingview.py'
--- softwarecenter/view/pendingview.py	2010-01-28 08:41:52 +0000
+++ softwarecenter/view/pendingview.py	2010-02-02 01:04:28 +0000
@@ -94,7 +94,7 @@
             appname = trans.meta_data["sc_appname"]
         except KeyError:
             #FIXME: Extract information from packages property
-            appname = get_role_localised_present_from_enum(role)
+            appname = get_role_localised_present_from_enum(trans.role)
             self._signals.append(
                 trans.connect("role-changed", self._on_role_changed))
         try:

=== modified file 'softwarecenter/view/viewswitcher.py'
--- softwarecenter/view/viewswitcher.py	2010-01-28 08:41:52 +0000
+++ softwarecenter/view/viewswitcher.py	2010-02-02 01:04:28 +0000
@@ -31,6 +31,8 @@
 
 from gettext import gettext as _
 
+from softwarecenter.enums import *
+from softwarecenter.db.database import StoreDatabase
 from softwarecenter.backend.transactionswatcher import TransactionsWatcher
 from widgets.animatedimage import CellRendererAnimatedImage, AnimatedImage
 
@@ -44,12 +46,12 @@
     }
 
 
-    def __init__(self, datadir, icons, store=None):
+    def __init__(self, datadir, db, icons, store=None):
         super(ViewSwitcher, self).__init__()
         self.datadir = datadir
         self.icons = icons
         if not store:
-            store = ViewSwitcherList(datadir, icons)
+            store = ViewSwitcherList(datadir, db, icons)
             # FIXME: this is just set here for app.py, make the
             #        transactions-changed signal part of the view api
             #        instead of the model
@@ -132,7 +134,8 @@
     # columns
     (COL_ICON,
      COL_NAME,
-     COL_ACTION) = range(3)
+     COL_ACTION,
+     COL_ACTION_DETAILS) = range(4)
 
     # items in the treeview
     (ACTION_ITEM_AVAILABLE,
@@ -149,11 +152,12 @@
                                               (int, )),
                      }
 
-    def __init__(self, datadir, icons):
-        gtk.TreeStore.__init__(self, AnimatedImage, str, int)
+    def __init__(self, datadir, db, icons):
+        gtk.TreeStore.__init__(self, AnimatedImage, str, int, str)
         TransactionsWatcher.__init__(self)
         self.icons = icons
         self.datadir = datadir
+        self.db = db
         # pending transactions
         self._pending = 0
         # setup the normal stuff
@@ -162,7 +166,7 @@
         else:
             icon = AnimatedImage(self.icons.load_icon("gtk-missing-image", 
                                                       self.ICON_SIZE, 0))
-        piter = self.append(None, [icon, _("Get Software"), self.ACTION_ITEM_AVAILABLE])
+        piter = self.append(None, [icon, _("Get Software"), self.ACTION_ITEM_AVAILABLE, ""])
         
         if self.icons.lookup_icon("distributor-logo", self.ICON_SIZE, 0):
             icon = AnimatedImage(self.icons.load_icon("distributor-logo", self.ICON_SIZE, 0))
@@ -170,12 +174,18 @@
             # icon not present in theme, probably because running uninstalled
             icon = AnimatedImage(self.icons.load_icon("gtk-missing-image", 
                                                       self.ICON_SIZE, 0))
-        self.append(piter, [icon, _("Free Software"), self.ACTION_ITEM_AVAILABLE])
+        
+        # add labels
+        for it in self.db.xapiandb.allterms("XOL"):
+            term = it.term[3:]
+            if not term:
+                term = _("Unknown")
+            self.append(piter, [icon, term, self.ACTION_ITEM_AVAILABLE, ""])
         
         icon = AnimatedImage(self.icons.load_icon("computer", self.ICON_SIZE, 0))
-        self.append(None, [icon, _("Installed Software"), self.ACTION_ITEM_INSTALLED])
+        self.append(None, [icon, _("Installed Software"), self.ACTION_ITEM_INSTALLED, ""])
         icon = AnimatedImage(None)
-        self.append(None, [icon, "<span size='1'> </span>", self.ACTION_ITEM_SEPARATOR_1])
+        self.append(None, [icon, "<span size='1'> </span>", self.ACTION_ITEM_SEPARATOR_1, ""])
 
     def on_transactions_changed(self, current, queue):
         #print "check_pending"
@@ -217,7 +227,14 @@
 
     scroll = gtk.ScrolledWindow()
     icons = gtk.icon_theme_get_default()
-    view = ViewSwitcher(datadir, icons)
+
+    xapian_base_path = XAPIAN_BASE_PATH
+    pathname = os.path.join(xapian_base_path, "xapian")
+    cache = apt.Cache(apt.progress.OpTextProgress())
+    db = StoreDatabase(pathname, cache)
+    db.open()
+
+    view = ViewSwitcher(datadir, db, icons)
 
     box = gtk.VBox()
     box.pack_start(scroll)

